about summary refs log tree commit diff
path: root/pkgs/build-support
diff options
context:
space:
mode:
authorMartin Messer <martin.messer@cyberus-technology.de>2022-12-20 13:53:03 +0100
committerMartin Messer <martin.messer@cyberus-technology.de>2023-12-07 16:56:16 +0100
commit6db96122047fe7bdc1d58e201c9d161c0c479aba (patch)
tree4b6d959a01c1b33d506b285f627cbb58fb8467ec /pkgs/build-support
parentddfddf4b719134ac0acd04595372ca1bde4d0879 (diff)
rename: incremental -> checkpointed builds
Diffstat (limited to 'pkgs/build-support')
-rw-r--r--pkgs/build-support/checkpoint-build.nix (renamed from pkgs/build-support/build-incremental.nix)28
1 files changed, 14 insertions, 14 deletions
diff --git a/pkgs/build-support/build-incremental.nix b/pkgs/build-support/checkpoint-build.nix
index e7bbf38710698..be25ca4d04b1c 100644
--- a/pkgs/build-support/build-incremental.nix
+++ b/pkgs/build-support/checkpoint-build.nix
@@ -2,24 +2,24 @@
 rec {
   /* Prepare a derivation for local builds.
     *
     * This function prepares incremental builds by provinding,
     * containing the build output and the sources for cross checking.
     * The build output can be used later to allow incremental builds
     * by passing the derivation output to the `mkIncrementalBuild` function.
     *
-    * To build a project incrementaly follow these steps:
+    * To build a project with checkpoints follow these steps:
     * - run prepareIncrementalBuild on the desired derivation
-    *   e.G `incrementalBuildArtifacts = (pkgs.buildIncremental.prepareIncrementalBuild pkgs.virtualbox);`
+    *   e.G `incrementalBuildArtifacts = (pkgs.checkpointBuildTools.prepareCheckpointBuild pkgs.virtualbox);`
     * - change something you want in the sources of the package( e.G using source override)
     *   changedVBox = pkgs.virtuabox.overrideAttrs (old: {
     *      src = path/to/vbox/sources;
     *   }
-    * - use `mkIncrementalBuild changedVBox buildOutput`
+    * - use `mkCheckpointedBuild changedVBox buildOutput`
     * - enjoy shorter build times
   */
-  prepareIncrementalBuild = drv: drv.overrideAttrs (old: {
+  prepareCheckpointBuild = drv: drv.overrideAttrs (old: {
     outputs = [ "out" ];
-    name = drv.name + "-incrementalBuildArtifacts";
+    name = drv.name + "-checkpointArtifacts";
     # To determine differences between the state of the build directory
     # from an earlier build and  a later one we store the state of the build
     # directory before build, but after patch phases.
@@ -41,16 +41,16 @@ rec {
     '';
   });
 
-  /* Build a derivation incrementally based on the output generated by
-    * the `prepareIncrementalBuild function.
+  /* Build a derivation based on the checkpoint output generated by
+    * the `prepareCheckpointBuild function.
     *
     * Usage:
     * let
-    *   incrementalBuildArtifacts = prepareIncrementalBuild drv
-    * in mkIncrementalBuild drv incrementalBuildArtifacts
+    *   checkpointArtifacts = prepareCheckpointBuild drv
+    * in mkCheckpointedBuild drv checkpointArtifacts
   */
-  mkIncrementalBuild = drv: previousBuildArtifacts: drv.overrideAttrs (old: {
-    # The actual incremental build phase.
+  mkCheckpointedBuild = drv: previousBuildArtifacts: drv.overrideAttrs (old: {
+    # The actual checkpoint build phase.
     # We compare the changed sources from a previous build with the current and create a patch
     # Afterwards we clean the build directory to copy the previous output files (Including the sources)
     # The source difference patch is applied to get the latest changes again to allow short build times.
@@ -2,24 +2,24 @@
   /* Prepare a derivation for local builds.
     *
-    * This function prepares incremental builds by provinding,
+    * This function prepares checkpoint builds by provinding,
     * containing the build output and the sources for cross checking.
@@ -2,24 +2,24 @@
     * containing the build output and the sources for cross checking.
-    * The build output can be used later to allow incremental builds
-    * by passing the derivation output to the `mkIncrementalBuild` function.
+    * The build output can be used later to allow checkpoint builds
+    * by passing the derivation output to the `mkCheckpointBuild` function.
     *